==> db4o_7.4.121.14026+dfsg.orig.tar.gz: db4o-7.4.121.14026+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Staging/ActivateDepthTestCase.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using Db4oUnit;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Config;
using Db4objects.Db4o.Tests.Common.Staging;

namespace Db4objects.Db4o.Tests.Common.Staging
{
	/// <exclude></exclude>
	public class ActivateDepthTestCase : AbstractDb4oTestCase
	{
		public static void Main(string[] args)
		{
			new ActivateDepthTestCase().RunAll();
		}

		public class Data
		{
			public int value;

			public Data(int i)
			{
				value = i;
			}
		}

		/// <exception cref="System.Exception"></exception>
		protected override void Configure(IConfiguration config)
		{
			config.ActivationDepth(0);
		}

		/// <exception cref="System.Exception"></exception>
		protected override void Store()
		{
			Store(new ActivateDepthTestCase.Data(42));
		}

		/// <exception cref="System.Exception"></exception>
		public virtual void Test()
		{
			ActivateDepthTestCase.Data data = (ActivateDepthTestCase.Data)RetrieveOnlyInstance
				(typeof(ActivateDepthTestCase.Data));
			Assert.AreEqual(0, data.value);
		}
	}
}

==> db4o_8.0.184.15484+dfsg2.orig.tar.gz: db4o-8.0.184.15484+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Staging/ActivateDepthTestCase.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using Db4oUnit;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Config;
using Db4objects.Db4o.Tests.Common.Staging;

namespace Db4objects.Db4o.Tests.Common.Staging
{
	/// <exclude></exclude>
	public class ActivateDepthTestCase : AbstractDb4oTestCase
	{
		public static void Main(string[] args)
		{
			new ActivateDepthTestCase().RunAll();
		}

		public class Data
		{
			public int value;

			public Data(int i)
			{
				value = i;
			}
		}

		/// <exception cref="System.Exception"></exception>
		protected override void Configure(IConfiguration config)
		{
			config.ActivationDepth(0);
		}

		/// <exception cref="System.Exception"></exception>
		protected override void Store()
		{
			Store(new ActivateDepthTestCase.Data(42));
		}

		/// <exception cref="System.Exception"></exception>
		public virtual void Test()
		{
			ActivateDepthTestCase.Data data = (ActivateDepthTestCase.Data)((ActivateDepthTestCase.Data
				)RetrieveOnlyInstance(typeof(ActivateDepthTestCase.Data)));
			Assert.AreEqual(0, data.value);
		}
	}
}
